@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,10 +24,11 @@
 #include "../Framework/Inputs/DicomPyramid.h"
 #include "../Framework/Inputs/TiledPyramidStatistics.h"
 #include "../Framework/Outputs/HierarchicalTiffWriter.h"
+#include "../Resources/Orthanc/Stone/OrthancHttpConnection.h"
 
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
-#include <Plugins/Samples/Common/OrthancHttpConnection.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <OrthancException.h>
 
 #include "ApplicationToolbox.h"
 
@@ -159,7 +160,7 @@ static bool ParseParameters(int& exitStatus,
 static Orthanc::ImageAccessor* CreateEmptyTile(const OrthancWSI::IPyramidWriter& writer,
                                                const boost::program_options::variables_map& options)
 {
-  std::auto_ptr<Orthanc::ImageAccessor> tile
+  std::unique_ptr<Orthanc::ImageAccessor> tile
     (OrthancWSI::ImageToolbox::Allocate(writer.GetPixelFormat(), 
                                         writer.GetTileWidth(), 
                                         writer.GetTileHeight()));
@@ -198,11 +199,12 @@ static void Run(OrthancWSI::ITiledPyramid& source,
     targetPhotometric = source.GetPhotometricInterpretation();
   }
 
+  OrthancWSI::ImageToolbox::CheckConstantTileSize(source); // (**)
   OrthancWSI::HierarchicalTiffWriter target(options[OPTION_OUTPUT].as<std::string>(),
                                             source.GetPixelFormat(), 
                                             OrthancWSI::ImageCompression_Jpeg,  // (*)
-                                            source.GetTileWidth(), 
-                                            source.GetTileHeight(),
+                                            source.GetTileWidth(0),   // (**) 
+                                            source.GetTileHeight(0),  // (**)
                                             targetPhotometric);
 
   if (options.count(OPTION_JPEG_QUALITY))
@@ -213,7 +215,7 @@ static void Run(OrthancWSI::ITiledPyramid& source,
   LOG(WARNING) << "Source photometric interpretation: " << EnumerationToString(source.GetPhotometricInterpretation());
   LOG(WARNING) << "Target photometric interpretation: " << EnumerationToString(targetPhotometric);
 
-  std::auto_ptr<Orthanc::ImageAccessor> empty(CreateEmptyTile(target, options));
+  std::unique_ptr<Orthanc::ImageAccessor> empty(CreateEmptyTile(target, options));
 
   for (unsigned int level = 0; level < source.GetLevelCount(); level++)
   {
@@ -228,10 +230,10 @@ static void Run(OrthancWSI::ITiledPyramid& source,
                  << " level " << level;
 
     unsigned int countX = OrthancWSI::CeilingDivision
-      (source.GetLevelWidth(level), source.GetTileWidth());
+      (source.GetLevelWidth(level), source.GetTileWidth(level));
 
     unsigned int countY = OrthancWSI::CeilingDivision
-      (source.GetLevelHeight(level), source.GetTileHeight());
+      (source.GetLevelHeight(level), source.GetTileHeight(level));
 
     for (unsigned int tileY = 0; tileY < countY; tileY++)
     {
@@ -254,12 +256,13 @@ static void Run(OrthancWSI::ITiledPyramid& source,
           }
           else if (reencode)
           {
-            std::auto_ptr<Orthanc::ImageAccessor> decoded;
+            std::unique_ptr<Orthanc::ImageAccessor> decoded;
 
             if (compression == OrthancWSI::ImageCompression_None)
             {
-              decoded.reset(OrthancWSI::ImageToolbox::DecodeRawTile(tile, source.GetPixelFormat(),
-                                                                    source.GetTileWidth(), source.GetTileHeight()));
+              decoded.reset(OrthancWSI::ImageToolbox::DecodeRawTile(
+                              tile, source.GetPixelFormat(),
+                              source.GetTileWidth(level), source.GetTileHeight(level)));
             }
             else
             {
@@ -318,7 +321,7 @@ int main(int argc, char* argv[])
 
       OrthancWSI::ApplicationToolbox::SetupRestApi(params, options);
 
-      OrthancPlugins::OrthancHttpConnection orthanc(params);
+      OrthancStone::OrthancHttpConnection orthanc(params);
       OrthancWSI::DicomPyramid source(orthanc, options[OPTION_INPUT].as<std::string>(), 
                                       false /* don't use cached metadata */);
 
