@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,6 +23,7 @@
 #include "../Framework/Algorithms/TranscodeTileCommand.h"
 #include "../Framework/DicomToolbox.h"
 #include "../Framework/DicomizerParameters.h"
+#include "../Framework/ImageToolbox.h"
 #include "../Framework/ImagedVolumeParameters.h"
 #include "../Framework/Inputs/HierarchicalTiff.h"
 #include "../Framework/Inputs/OpenSlidePyramid.h"
@@ -33,10 +34,12 @@
 #include "../Framework/Outputs/DicomPyramidWriter.h"
 #include "../Framework/Outputs/TruncatedPyramidWriter.h"
 
-#include <Core/DicomParsing/FromDcmtkBridge.h>
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
-#include <Core/SystemToolbox.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <DicomParsing/FromDcmtkBridge.h>
+#include <Logging.h>
+#include <OrthancException.h>
+#include <Toolbox.h>
+#include <SystemToolbox.h>
 
 #include "ApplicationToolbox.h"
 
@@ -80,6 +83,28 @@ static const char* OPTION_VERBOSE = "verbose";
 static const char* OPTION_VERSION = "version";
 
 
+#if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 9, 0)
+
+bool ReadJsonWithoutComments(Json::Value& target,
+                             const std::string& source)
+{
+  return Orthanc::Toolbox::ReadJsonWithoutComments(target, source);
+}
+
+#else
+
+// Backward compatibility with Orthanc framework <= 1.8.2
+#include <json/reader.h>
+
+bool ReadJsonWithoutComments(Json::Value& target,
+                             const std::string& source)
+{
+  Json::Reader reader;
+  return reader.parse(source, target, false);
+}
+#endif
+
+
 static void TranscodePyramid(OrthancWSI::PyramidWriterBase& target,
                              OrthancWSI::ITiledPyramid& source,
                              const OrthancWSI::DicomizerParameters& parameters)
@@ -167,7 +192,8 @@ static void Recompress(OrthancWSI::IFileTarget& output,
 {
   OrthancWSI::TiledPyramidStatistics stats(source);
 
-  LOG(WARNING) << "Size of source tiles: " << stats.GetTileWidth() << "x" << stats.GetTileHeight();
+  OrthancWSI::ImageToolbox::CheckConstantTileSize(stats);  // Sanity check
+  LOG(WARNING) << "Size of source tiles: " << stats.GetTileWidth(0) << "x" << stats.GetTileHeight(0);
   LOG(WARNING) << "Pixel format: " << Orthanc::EnumerationToString(source.GetPixelFormat());
   LOG(WARNING) << "Source photometric interpretation: " << Orthanc::EnumerationToString(source.GetPhotometricInterpretation());
   LOG(WARNING) << "Source compression: " << EnumerationToString(sourceCompression);
@@ -249,8 +275,9 @@ static void Recompress(OrthancWSI::IFileTarget& output,
                  << OrthancWSI::EnumerationToString(target.GetImageCompression());
   }
 
-  if (stats.GetTileWidth() % target.GetTileWidth() != 0 ||
-      stats.GetTileHeight() % target.GetTileHeight() != 0)
+  OrthancWSI::ImageToolbox::CheckConstantTileSize(stats);
+  if (stats.GetTileWidth(0) % target.GetTileWidth() != 0 ||
+      stats.GetTileHeight(0) % target.GetTileHeight() != 0)
   {
     LOG(ERROR) << "When resampling the tile size, "
                << "it must be a integer divisor of the original tile size";
@@ -292,15 +319,14 @@ static DcmDataset* ParseDataset(const std::string& path)
     std::string content;
     Orthanc::SystemToolbox::ReadFile(content, path);
 
-    Json::Reader reader;
-    if (!reader.parse(content, json, false))
+    if (!ReadJsonWithoutComments(json, content))
     {
       LOG(ERROR) << "Cannot parse the JSON file in: " << path;
       throw Orthanc::OrthancException(Orthanc::ErrorCode_BadFileFormat);
     }
   }
 
-  std::auto_ptr<DcmDataset> dataset(Orthanc::FromDcmtkBridge::FromJson(json, true, true, Orthanc::Encoding_Latin1,
+  std::unique_ptr<DcmDataset> dataset(Orthanc::FromDcmtkBridge::FromJson(json, true, true, Orthanc::Encoding_Latin1,
                                                                        "" /* no private tag, thus no private creator */));
   if (dataset.get() == NULL)
   {
@@ -359,10 +385,10 @@ static void SetupDimension(DcmDataset& dataset,
 
   {
     // Construct tag "Dimension Organization Sequence" (0020,9221)
-    std::auto_ptr<DcmItem> item(new DcmItem);
+    std::unique_ptr<DcmItem> item(new DcmItem);
     OrthancWSI::DicomToolbox::SetStringTag(*item, DCM_DimensionOrganizationUID, organization);
     
-    std::auto_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_DimensionOrganizationSequence));
+    std::unique_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_DimensionOrganizationSequence));
 
     if (!sequence->insert(item.release(), false, false).good() ||
         !dataset.insert(sequence.release(), true /* replace */, false).good())
@@ -374,17 +400,17 @@ static void SetupDimension(DcmDataset& dataset,
 
   {
     // Construct tag "Dimension Index Sequence" (0020,9222)
-    std::auto_ptr<DcmItem> item(new DcmItem);
+    std::unique_ptr<DcmItem> item(new DcmItem);
     OrthancWSI::DicomToolbox::SetStringTag(*item, DCM_DimensionOrganizationUID, organization);
     OrthancWSI::DicomToolbox::SetAttributeTag(*item, DCM_FunctionalGroupPointer, DCM_PlanePositionSlideSequence);
     OrthancWSI::DicomToolbox::SetAttributeTag(*item, DCM_DimensionIndexPointer, DCM_ColumnPositionInTotalImagePixelMatrix);
 
-    std::auto_ptr<DcmItem> item2(new DcmItem);
+    std::unique_ptr<DcmItem> item2(new DcmItem);
     OrthancWSI::DicomToolbox::SetStringTag(*item2, DCM_DimensionOrganizationUID, organization);
     OrthancWSI::DicomToolbox::SetAttributeTag(*item2, DCM_FunctionalGroupPointer, DCM_PlanePositionSlideSequence);
     OrthancWSI::DicomToolbox::SetAttributeTag(*item2, DCM_DimensionIndexPointer, DCM_RowPositionInTotalImagePixelMatrix);
 
-    std::auto_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_DimensionIndexSequence));
+    std::unique_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_DimensionIndexSequence));
 
     if (!sequence->insert(item.release(), false, false).good() ||
         !sequence->insert(item2.release(), false, false).good() ||
@@ -397,13 +423,13 @@ static void SetupDimension(DcmDataset& dataset,
 
   {
     // Construct tag "Shared Functional Groups Sequence" (5200,9229)
-    std::auto_ptr<DcmItem> item(new DcmItem);
+    std::unique_ptr<DcmItem> item(new DcmItem);
 
-    std::auto_ptr<DcmItem> item3(new DcmItem);
+    std::unique_ptr<DcmItem> item3(new DcmItem);
     OrthancWSI::DicomToolbox::SetStringTag(*item3, DCM_OpticalPathIdentifier, opticalPathId);
 
-    std::auto_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_SharedFunctionalGroupsSequence));
-    std::auto_ptr<DcmSequenceOfItems> sequence3(new DcmSequenceOfItems(DCM_OpticalPathIdentificationSequence));
+    std::unique_ptr<DcmSequenceOfItems> sequence(new DcmSequenceOfItems(DCM_SharedFunctionalGroupsSequence));
+    std::unique_ptr<DcmSequenceOfItems> sequence3(new DcmSequenceOfItems(DCM_OpticalPathIdentificationSequence));
 
     if (!sequence3->insert(item3.release(), false, false).good() ||
         !item->insert(sequence3.release(), false, false).good() ||
@@ -441,13 +467,13 @@ static void EnrichDataset(DcmDataset& dataset,
   OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeHeight, boost::lexical_cast<std::string>(volume.GetHeight()));
   OrthancWSI::DicomToolbox::SetStringTag(dataset, DCM_ImagedVolumeDepth, boost::lexical_cast<std::string>(volume.GetDepth()));
 
-  std::auto_ptr<DcmItem> origin(new DcmItem);
+  std::unique_ptr<DcmItem> origin(new DcmItem);
   OrthancWSI::DicomToolbox::SetStringTag(*origin, DCM_XOffsetInSlideCoordinateSystem, 
                                          boost::lexical_cast<std::string>(volume.GetOffsetX()));
   OrthancWSI::DicomToolbox::SetStringTag(*origin, DCM_YOffsetInSlideCoordinateSystem, 
                                          boost::lexical_cast<std::string>(volume.GetOffsetY()));
 
-  std::auto_ptr<DcmSequenceOfItems> sequenceOrigin(new DcmSequenceOfItems(DCM_TotalPixelMatrixOriginSequence));
+  std::unique_ptr<DcmSequenceOfItems> sequenceOrigin(new DcmSequenceOfItems(DCM_TotalPixelMatrixOriginSequence));
   if (!sequenceOrigin->insert(origin.release(), false, false).good() ||
       !dataset.insert(sequenceOrigin.release(), false, false).good())
   {
@@ -467,13 +493,12 @@ static void EnrichDataset(DcmDataset& dataset,
     Orthanc::EmbeddedResources::GetFileResource(brightfield, Orthanc::EmbeddedResources::BRIGHTFIELD_OPTICAL_PATH);
 
     Json::Value json;
-    Json::Reader reader;
-    if (!reader.parse(brightfield, json, false))
+    if (!ReadJsonWithoutComments(json, brightfield))
     {
       throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
     }
 
-    std::auto_ptr<DcmElement> element(Orthanc::FromDcmtkBridge::FromJson(
+    std::unique_ptr<DcmElement> element(Orthanc::FromDcmtkBridge::FromJson(
                                         Orthanc::DicomTag(DCM_OpticalPathSequence.getGroup(),
                                                           DCM_OpticalPathSequence.getElement()),
                                         json, false, encoding,
@@ -505,7 +530,7 @@ static void EnrichDataset(DcmDataset& dataset,
 
   if (!opticalPath->tagExists(DCM_ICCProfile))
   {
-    std::auto_ptr<DcmOtherByteOtherWord> icc(new DcmOtherByteOtherWord(DCM_ICCProfile));
+    std::unique_ptr<DcmOtherByteOtherWord> icc(new DcmOtherByteOtherWord(DCM_ICCProfile));
 
     if (!icc->putUint8Array(reinterpret_cast<const Uint8*>(profile.c_str()), profile.size()).good() ||
         !opticalPath->insert(icc.release()).good())
@@ -927,7 +952,7 @@ OrthancWSI::ITiledPyramid* OpenInputPyramid(OrthancWSI::ImageCompression& source
     {
       try
       {
-        std::auto_ptr<OrthancWSI::HierarchicalTiff> tiff(new OrthancWSI::HierarchicalTiff(path));
+        std::unique_ptr<OrthancWSI::HierarchicalTiff> tiff(new OrthancWSI::HierarchicalTiff(path));
         sourceCompression = tiff->GetImageCompression();
         return tiff.release();
       }
@@ -972,7 +997,7 @@ int main(int argc, char* argv[])
     if (ParseParameters(exitStatus, parameters, volume, argc, argv))
     {
       OrthancWSI::ImageCompression sourceCompression;
-      std::auto_ptr<OrthancWSI::ITiledPyramid> source;
+      std::unique_ptr<OrthancWSI::ITiledPyramid> source;
 
       source.reset(OpenInputPyramid(sourceCompression, parameters.GetInputFile(), parameters));
       if (source.get() == NULL)
@@ -983,10 +1008,10 @@ int main(int argc, char* argv[])
       LOG(WARNING) << "Compression of the individual source tiles: " << OrthancWSI::EnumerationToString(sourceCompression);
       
       // Create the shared DICOM tags
-      std::auto_ptr<DcmDataset> dataset(ParseDataset(parameters.GetDatasetPath()));
+      std::unique_ptr<DcmDataset> dataset(ParseDataset(parameters.GetDatasetPath()));
       EnrichDataset(*dataset, *source, sourceCompression, parameters, volume);
 
-      std::auto_ptr<OrthancWSI::IFileTarget> output(parameters.CreateTarget());
+      std::unique_ptr<OrthancWSI::IFileTarget> output(parameters.CreateTarget());
       Recompress(*output, *source, *dataset, parameters, volume, sourceCompression);
     }
   }
