@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,8 +23,10 @@
 #include "PyramidReader.h"
 
 #include "../ImageToolbox.h"
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
+
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <OrthancException.h>
 
 #include <cassert>
 
@@ -40,7 +42,7 @@ namespace OrthancWSI
     std::string       rawTile_;
     ImageCompression  rawTileCompression_;
 
-    std::auto_ptr<Orthanc::ImageAccessor>  decoded_;
+    std::unique_ptr<Orthanc::ImageAccessor>  decoded_;
 
     bool IsRepaintNeeded() const
     {
@@ -186,7 +188,7 @@ namespace OrthancWSI
         tile.GetHeight() != sourceTileHeight_)
     {
       LOG(ERROR) << "One tile in the input image has size " << tile.GetWidth() << "x" << tile.GetHeight() 
-                 << " instead of required " << source_.GetTileWidth() << "x" << source_.GetTileHeight();
+                 << " instead of required " << sourceTileWidth_ << "x" << sourceTileHeight_;
       throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageSize);
     }
   }
@@ -197,7 +199,7 @@ namespace OrthancWSI
   {
     if (parameters_.IsSafetyCheck())
     {
-      std::auto_ptr<Orthanc::ImageAccessor> decoded(ImageToolbox::DecodeTile(tile, compression));
+      std::unique_ptr<Orthanc::ImageAccessor> decoded(ImageToolbox::DecodeTile(tile, compression));
       CheckTileSize(*decoded);
     }
   }
@@ -236,8 +238,8 @@ namespace OrthancWSI
     level_(level),
     levelWidth_(source.GetLevelWidth(level)),
     levelHeight_(source.GetLevelHeight(level)),
-    sourceTileWidth_(source.GetTileWidth()),
-    sourceTileHeight_(source.GetTileHeight()),
+    sourceTileWidth_(source.GetTileWidth(level)),
+    sourceTileHeight_(source.GetTileHeight(level)),
     targetTileWidth_(targetTileWidth),
     targetTileHeight_(targetTileHeight),
     parameters_(parameters)
