@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,6 +24,8 @@
 #include "../Inputs/ITiledPyramid.h"
 #include "../DicomizerParameters.h"
 
+#include <Compatibility.h>  // For std::unique_ptr
+
 #include <map>
 #include <memory>
 
@@ -50,7 +52,7 @@ namespace OrthancWSI
 
     Cache           cache_;
 
-    std::auto_ptr<Orthanc::ImageAccessor>  outside_;
+    std::unique_ptr<Orthanc::ImageAccessor>  outside_;
 
 
     Orthanc::ImageAccessor& GetOutsideTile();
