@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,9 +23,12 @@
 #include "ReconstructPyramidCommand.h"
 
 #include "../ImageToolbox.h"
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
-#include <Core/Images/Image.h>
+
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <OrthancException.h>
+#include <Images/Image.h>
+#include <Images/ImageProcessing.h>
 
 #include <cassert>
 
@@ -46,7 +49,7 @@ namespace OrthancWSI
       return NULL;
     }
 
-    std::auto_ptr<Orthanc::ImageAccessor> result;
+    std::unique_ptr<Orthanc::ImageAccessor> result;
 
     if (level == 0)
     {
@@ -69,7 +72,7 @@ namespace OrthancWSI
     }
     else
     {
-      std::auto_ptr<Orthanc::ImageAccessor> mosaic(ImageToolbox::Allocate(source_.GetPixelFormat(), 
+      std::unique_ptr<Orthanc::ImageAccessor> mosaic(ImageToolbox::Allocate(source_.GetPixelFormat(), 
                                                                           2 * target_.GetTileWidth(), 
                                                                           2 * target_.GetTileHeight()));
       ImageToolbox::Set(*mosaic, 
@@ -78,7 +81,7 @@ namespace OrthancWSI
                         source_.GetParameters().GetBackgroundColorBlue());
 
       {
-        std::auto_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX, 2 * offsetY));
+        std::unique_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX, 2 * offsetY));
         if (subTile.get() != NULL)
         {
           ImageToolbox::Embed(*mosaic, *subTile, 0, 0);
@@ -86,7 +89,7 @@ namespace OrthancWSI
       }
 
       {
-        std::auto_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX + 1, 2 * offsetY));
+        std::unique_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX + 1, 2 * offsetY));
         if (subTile.get() != NULL)
         {
           ImageToolbox::Embed(*mosaic, *subTile, target_.GetTileWidth(), 0);
@@ -94,7 +97,7 @@ namespace OrthancWSI
       }
 
       {
-        std::auto_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX, 2 * offsetY + 1));
+        std::unique_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX, 2 * offsetY + 1));
         if (subTile.get() != NULL)
         {
           ImageToolbox::Embed(*mosaic, *subTile, 0, target_.GetTileHeight());
@@ -102,14 +105,19 @@ namespace OrthancWSI
       }
 
       {
-        std::auto_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX + 1, 2 * offsetY + 1));
+        std::unique_ptr<Orthanc::ImageAccessor> subTile(Explore(level - 1, 2 * offsetX + 1, 2 * offsetY + 1));
         if (subTile.get() != NULL)
         {
           ImageToolbox::Embed(*mosaic, *subTile, target_.GetTileWidth(), target_.GetTileHeight());
         }
       }
 
-      result.reset(ImageToolbox::Halve(*mosaic, source_.GetParameters().IsSmoothEnabled()));
+      if (source_.GetParameters().IsSmoothEnabled())
+      {
+        Orthanc::ImageProcessing::SmoothGaussian5x5(*mosaic, false /* don't use accurate rounding */);
+      }
+
+      result.reset(Orthanc::ImageProcessing::Halve(*mosaic, false /* don't force minimal pitch */));
 
       target_.EncodeTile(*result, level + shiftTargetLevel_, x, y);
     }
@@ -147,7 +155,7 @@ namespace OrthancWSI
 
   bool ReconstructPyramidCommand::Execute()
   {
-    std::auto_ptr<Orthanc::ImageAccessor> root(Explore(upToLevel_, 0, 0));
+    std::unique_ptr<Orthanc::ImageAccessor> root(Explore(upToLevel_, 0, 0));
     return true;
   }
 
@@ -177,7 +185,7 @@ namespace OrthancWSI
     {
       for (unsigned int x = 0; x < targetCountTilesX; x += step)
       {
-        std::auto_ptr<ReconstructPyramidCommand> command;
+        std::unique_ptr<ReconstructPyramidCommand> command;
         command.reset(new ReconstructPyramidCommand
                       (target, source, countLevels - 1, x, y, parameters));
         command->SetShiftTargetLevel(shiftTargetLevel);
