@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,8 +22,8 @@
 #include "../PrecompiledHeadersWSI.h"
 #include "TranscodeTileCommand.h"
 
-#include <Core/OrthancException.h>
-#include <Core/Logging.h>
+#include <OrthancException.h>
+#include <Logging.h>
 
 #include <cassert>
 
@@ -91,15 +91,15 @@ namespace OrthancWSI
                                                ITiledPyramid& source,
                                                const DicomizerParameters& parameters)
   {
-    const unsigned int stepX = source.GetTileWidth() / target.GetTileWidth();
-    const unsigned int stepY = source.GetTileHeight() / target.GetTileHeight();
-    assert(stepX >= 1 && stepY >= 1);
-
     for (unsigned int level = 0; level < source.GetLevelCount(); level++)
     {
       const unsigned int targetCountTilesX = target.GetCountTilesX(level);
       const unsigned int targetCountTilesY = target.GetCountTilesY(level);
 
+      const unsigned int stepX = source.GetTileWidth(level) / target.GetTileWidth();
+      const unsigned int stepY = source.GetTileHeight(level) / target.GetTileHeight();
+      assert(stepX >= 1 && stepY >= 1);
+
       for (unsigned int y = 0; y < targetCountTilesY; y += stepY)
       {
         unsigned int cy = stepY;
