@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -49,7 +49,7 @@ namespace OrthancWSI
                          unsigned int countTilesY,
                          const DicomizerParameters& parameters);
 
-    virtual bool Execute();
+    virtual bool Execute() ORTHANC_OVERRIDE;
 
     static void PrepareBagOfTasks(Orthanc::BagOfTasks& tasks,
                                   IPyramidWriter& target,
