@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,12 +22,14 @@
 #include "PrecompiledHeadersWSI.h"
 #include "DicomToolbox.h"
 
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
-#include <Core/Toolbox.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <OrthancException.h>
+#include <Toolbox.h>
 
 #if ORTHANC_ENABLE_DCMTK == 1
 #  include <dcmtk/dcmdata/dcelem.h>
+#  include <dcmtk/dcmdata/dcitem.h>
 #  include <dcmtk/dcmdata/dcsequen.h>
 #  include <dcmtk/dcmdata/dcvrat.h>
 #endif
@@ -78,7 +80,7 @@ namespace OrthancWSI
     {
       if (!dataset.tagExists(key))
       {
-        std::auto_ptr<DcmAttributeTag> tag(new DcmAttributeTag(key));
+        std::unique_ptr<DcmAttributeTag> tag(new DcmAttributeTag(key));
         
         if (!tag->putTagVal(value).good() ||
             !dataset.insert(tag.release()).good())
@@ -93,7 +95,7 @@ namespace OrthancWSI
                                        const DcmTagKey& key)
     {
       DcmElement* element = NULL;
-      if (!const_cast<DcmItem&>(dataset).findAndGetElement(key, element).good() ||
+      if (!dataset.findAndGetElement(key, element).good() ||
           element == NULL)
       {
         return NULL;
