@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,10 +22,11 @@
 #include "PrecompiledHeadersWSI.h"
 #include "DicomizerParameters.h"
 
+#include "ImageToolbox.h"
 #include "Targets/FolderTarget.h"
 #include "Targets/OrthancTarget.h"
 
-#include <Core/OrthancException.h>
+#include <OrthancException.h>
 
 #include <boost/thread.hpp>
 #include <boost/lexical_cast.hpp>
@@ -111,6 +112,13 @@ namespace OrthancWSI
   }
 
 
+  unsigned int DicomizerParameters::GetTargetTileWidth(const ITiledPyramid& source) const
+  {
+    ImageToolbox::CheckConstantTileSize(source);
+    return GetTargetTileWidth(source.GetTileWidth(0));
+  }
+  
+
   unsigned int DicomizerParameters::GetTargetTileHeight(unsigned int defaultHeight) const
   {
     if (hasTargetTileSize_ &&
@@ -125,6 +133,13 @@ namespace OrthancWSI
   }
 
 
+  unsigned int DicomizerParameters::GetTargetTileHeight(const ITiledPyramid& source) const
+  {
+    ImageToolbox::CheckConstantTileSize(source);
+    return GetTargetTileHeight(source.GetTileHeight(0));
+  }
+
+
   void DicomizerParameters::SetThreadsCount(unsigned int threads)
   {
     if (threads == 0)
@@ -161,6 +176,8 @@ namespace OrthancWSI
       return pyramidLevelsCount_;
     }
 
+    ImageToolbox::CheckConstantTileSize(source);
+
     // By default, the number of levels for the pyramid is taken so that
     // the upper level is reduced either to 1 column of tiles, or to 1
     // row of tiles.
@@ -205,8 +222,8 @@ namespace OrthancWSI
     }
 
     unsigned int fullNumberOfTiles = (
-      CeilingDivision(source.GetLevelWidth(0), source.GetTileWidth()) * 
-      CeilingDivision(source.GetLevelHeight(0), source.GetTileHeight()));
+      CeilingDivision(source.GetLevelWidth(0), source.GetTileWidth(0)) * 
+      CeilingDivision(source.GetLevelHeight(0), source.GetTileHeight(0)));
 
     // By default, the number of lower levels in the pyramid is chosen
     // as a compromise between the number of tasks (there should not be
