@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,7 +25,7 @@
 #include "Outputs/IPyramidWriter.h"
 #include "Targets/IFileTarget.h"
 #include "DicomToolbox.h"
-#include <Core/WebServiceParameters.h>
+#include <WebServiceParameters.h>
 
 #include <stdint.h>
 
@@ -115,17 +115,11 @@ namespace OrthancWSI
 
     unsigned int GetTargetTileWidth(unsigned int defaultWidth) const;
 
-    unsigned int GetTargetTileWidth(const ITiledPyramid& source) const
-    {
-      return GetTargetTileWidth(source.GetTileWidth());
-    }
+    unsigned int GetTargetTileWidth(const ITiledPyramid& source) const;
 
     unsigned int GetTargetTileHeight(unsigned int defaultHeight) const;
 
-    unsigned int GetTargetTileHeight(const ITiledPyramid& source) const
-    {
-      return GetTargetTileHeight(source.GetTileHeight());
-    }
+    unsigned int GetTargetTileHeight(const ITiledPyramid& source) const;
 
     void SetThreadsCount(unsigned int threads);
 
