@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,9 +23,11 @@
 #include "Enumerations.h"
 
 #include "Jpeg2000Reader.h"
-#include <Core/OrthancException.h>
-#include <Core/SystemToolbox.h>
-#include <Core/Toolbox.h>
+
+#include <Logging.h>
+#include <OrthancException.h>
+#include <SystemToolbox.h>
+#include <Toolbox.h>
 
 #include <string.h>
 #include <boost/algorithm/string/predicate.hpp>
