@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,22 +21,24 @@
 
 #pragma once
 
-#include <Core/Enumerations.h>
+#include <Enumerations.h>
 
 #include <stdint.h>
 #include <string>
 
 namespace OrthancWSI
 {
+  // WARNING - Don't change the enum values below, as this would break
+  // serialization of "DicomPyramidInstance"
   enum ImageCompression
   {
-    ImageCompression_Unknown,
-    ImageCompression_None,
-    ImageCompression_Dicom,
-    ImageCompression_Png,
-    ImageCompression_Jpeg,
-    ImageCompression_Jpeg2000,
-    ImageCompression_Tiff
+    ImageCompression_Unknown = 1,
+    ImageCompression_None = 2,
+    ImageCompression_Dicom = 3,
+    ImageCompression_Png = 4,
+    ImageCompression_Jpeg = 5,
+    ImageCompression_Jpeg2000 = 6,
+    ImageCompression_Tiff = 7
   };
 
   enum OpticalPath
