@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -25,13 +25,14 @@
 #include "Jpeg2000Reader.h"
 #include "Jpeg2000Writer.h"
 
-#include <Core/OrthancException.h>
-#include <Core/Images/ImageProcessing.h>
-#include <Core/Images/PngReader.h>
-#include <Core/Images/PngWriter.h>
-#include <Core/Images/JpegReader.h>
-#include <Core/Images/JpegWriter.h>
-#include <Core/Logging.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <OrthancException.h>
+#include <Images/ImageProcessing.h>
+#include <Images/PngReader.h>
+#include <Images/PngWriter.h>
+#include <Images/JpegReader.h>
+#include <Images/JpegWriter.h>
+#include <Logging.h>
 
 #include <string.h>
 #include <memory>
@@ -49,7 +50,7 @@ namespace OrthancWSI
     }
 
 
-    void Embed(Orthanc::ImageAccessor& target,
+    void Embed(const Orthanc::ImageAccessor& target,
                const Orthanc::ImageAccessor& source,
                unsigned int x,
                unsigned int y)
@@ -82,43 +83,24 @@ namespace OrthancWSI
              uint8_t g,
              uint8_t b)
     {
-      if (image.GetWidth() == 0 ||
-          image.GetHeight() == 0)
-      {
-        return;
-      }
-
-      uint8_t grayscale = (2126 * static_cast<uint16_t>(r) + 
-                           7152 * static_cast<uint16_t>(g) +
-                           0722 * static_cast<uint16_t>(b)) / 10000;
-
       switch (image.GetFormat())
       {
         case Orthanc::PixelFormat_Grayscale8:
         {
-          for (unsigned int y = 0; y < image.GetHeight(); y++)
-          {
-            memset(image.GetRow(y), grayscale, image.GetWidth());
-          }
-
+#if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 9, 0)
+          Orthanc::ImageProcessing::Set(image, r, g, b, 0 /* alpha is ignored */);
+#else
+          uint8_t grayscale = (2126 * static_cast<uint16_t>(r) + 
+                               7152 * static_cast<uint16_t>(g) +
+                               0722 * static_cast<uint16_t>(b)) / 10000;
+          Orthanc::ImageProcessing::Set(image, grayscale);
+#endif
           break;
         }
 
         case Orthanc::PixelFormat_RGB24:
-        {
-          for (unsigned int y = 0; y < image.GetHeight(); y++)
-          {
-            uint8_t* p = reinterpret_cast<uint8_t*>(image.GetRow(y));
-            for (unsigned int x = 0; x < image.GetWidth(); x++, p += 3)
-            {
-              p[0] = r;
-              p[1] = g;
-              p[2] = b;
-            }
-          }
-
+          Orthanc::ImageProcessing::Set(image, r, g, b, 0 /* alpha is ignored */);
           break;
-        }
 
         default:
           throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented);
@@ -133,21 +115,21 @@ namespace OrthancWSI
       {
         case ImageCompression_Png:
         {
-          std::auto_ptr<Orthanc::PngReader> reader(new Orthanc::PngReader);
+          std::unique_ptr<Orthanc::PngReader> reader(new Orthanc::PngReader);
           reader->ReadFromMemory(source);
           return reader.release();
         }
 
         case ImageCompression_Jpeg:
         {
-          std::auto_ptr<Orthanc::JpegReader> reader(new Orthanc::JpegReader);
+          std::unique_ptr<Orthanc::JpegReader> reader(new Orthanc::JpegReader);
           reader->ReadFromMemory(source);
           return reader.release();
         }
 
         case ImageCompression_Jpeg2000:
         {
-          std::auto_ptr<Jpeg2000Reader> reader(new Jpeg2000Reader);
+          std::unique_ptr<Jpeg2000Reader> reader(new Jpeg2000Reader);
           reader->ReadFromMemory(source);
           return reader.release();
         }
@@ -187,14 +169,15 @@ namespace OrthancWSI
         unsigned int pitch = GetBytesPerPixel(source.GetFormat()) * source.GetWidth();
         target.resize(pitch * source.GetHeight());
 
-        for (unsigned int i = 0; i < source.GetHeight(); i++)
+        const unsigned int height = source.GetHeight();
+        for (unsigned int i = 0; i < height; i++)
         {
           memcpy(&target[i * pitch], source.GetConstRow(i), pitch);
         }
       }
       else
       {
-        std::auto_ptr<Orthanc::IImageWriter> writer;
+        std::unique_ptr<Orthanc::IImageWriter> writer;
 
         switch (compression)
         {
@@ -215,7 +198,7 @@ namespace OrthancWSI
             throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
         }
 
-        writer->WriteToMemory(target, source);
+        Orthanc::IImageWriter::WriteToMemory(*writer, target, source);
       }
     }
 
@@ -232,162 +215,117 @@ namespace OrthancWSI
       }
       else
       {
-        std::auto_ptr<Orthanc::ImageAccessor> decoded(DecodeTile(source, sourceCompression));
+        std::unique_ptr<Orthanc::ImageAccessor> decoded(DecodeTile(source, sourceCompression));
         EncodeTile(target, *decoded, targetCompression, quality);
       }
     }
 
 
-    static uint8_t GetPixelValue(const Orthanc::ImageAccessor& source,
-                                 unsigned int x,
-                                 unsigned int y,
-                                 unsigned int channel,
-                                 int offsetX,
-                                 int offsetY,
-                                 unsigned int bytesPerPixel)
-    {
-      assert(bytesPerPixel == source.GetBytesPerPixel());
-      assert(channel < bytesPerPixel);
-      assert(source.GetFormat() == Orthanc::PixelFormat_Grayscale8 ||
-             source.GetFormat() == Orthanc::PixelFormat_RGB24 ||
-             source.GetFormat() == Orthanc::PixelFormat_RGBA32);  // 16bpp is unsupported
-
-      if (static_cast<int>(x) + offsetX < 0)
-      {
-        x = 0;
-      }
-      else
-      {
-        x += offsetX;
-        if (x >= source.GetWidth())
-        {
-          x = source.GetWidth() - 1;
-        }
-      }
-
-      if (static_cast<int>(y) + offsetY < 0)
-      {
-        y = 0;
-      }
-      else
-      {
-        y += offsetY;
-        if (y >= source.GetHeight())
-        {
-          y = source.GetHeight() - 1;
-        }
-      }
-
-      return *(reinterpret_cast<const uint8_t*>(source.GetConstBuffer()) +
-               y * source.GetPitch() + x * bytesPerPixel + channel);
-    }
-
-
-    static uint8_t SmoothPixelValue(const Orthanc::ImageAccessor& source,
-                                    unsigned int x,
-                                    unsigned int y,
-                                    unsigned int channel,
-                                    unsigned int bytesPerPixel)
-    {
-      static const uint32_t kernel[5] = { 1, 4, 6, 4, 1 };
-      static const uint32_t normalization = 2 * (1 + 4 + 6 + 4 + 1);
-
-      uint32_t accumulator = 0;
-
-      // Horizontal smoothing
-      for (int offset = -2; offset <= 2; offset++)
-      {
-        accumulator += kernel[offset + 2] * GetPixelValue(source, x, y, channel, offset, 0, bytesPerPixel);
-      }
-
-      // Vertical smoothing
-      for (int offset = -2; offset <= 2; offset++)
-      {
-        accumulator += kernel[offset + 2] * GetPixelValue(source, x, y, channel, 0, offset, bytesPerPixel);
-      }
-
-      return static_cast<uint8_t>(accumulator / normalization);
-    }
-
-
-    Orthanc::ImageAccessor* Halve(const Orthanc::ImageAccessor& source,
-                                  bool smooth)
-    {
-      if (source.GetWidth() % 2 == 1 ||
-          source.GetHeight() % 2 == 1)
-      {
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageSize);
-      }
-
-      if (source.GetFormat() != Orthanc::PixelFormat_Grayscale8 &&
-          source.GetFormat() != Orthanc::PixelFormat_RGB24 &&
-          source.GetFormat() != Orthanc::PixelFormat_RGBA32)  // 16bpp is not supported (*)
-      {
-        throw Orthanc::OrthancException(Orthanc::ErrorCode_NotImplemented);
-      }
-
-      const unsigned int bytesPerPixel = source.GetBytesPerPixel();  // Corresponds to the number of channels tx (*)
-
-      std::auto_ptr<Orthanc::ImageAccessor> target(Allocate(source.GetFormat(), 
-                                                            source.GetWidth() / 2, 
-                                                            source.GetHeight() / 2));
-
-      for (unsigned int y = 0; y < target->GetHeight(); y++)
-      {
-        uint8_t* q = reinterpret_cast<uint8_t*>(target->GetRow(y));
-
-        for (unsigned int x = 0; x < target->GetWidth(); x++, q += bytesPerPixel)
-        {
-          for (unsigned int c = 0; c < bytesPerPixel; c++)
-          {
-            if (smooth)
-            {
-              q[c] = SmoothPixelValue(source, 2 * x, 2 * y, c, bytesPerPixel);
-            }
-            else
-            {
-              q[c] = GetPixelValue(source, 2 * x, 2 * y, c, 0, 0, bytesPerPixel);
-            }
-          }
-        }
-      }
-
-      return target.release();
-    }
-
-
-    Orthanc::ImageAccessor* Clone(const Orthanc::ImageAccessor& accessor)
-    {
-      std::auto_ptr<Orthanc::ImageAccessor> result(Allocate(accessor.GetFormat(),
-                                                            accessor.GetWidth(),
-                                                            accessor.GetHeight()));
-      Embed(*result, accessor, 0, 0);
-
-      return result.release();
-    }
-
-
     Orthanc::ImageAccessor* Render(ITiledPyramid& pyramid,
                                    unsigned int level)
     {
-      std::auto_ptr<Orthanc::ImageAccessor> result(Allocate(pyramid.GetPixelFormat(), 
-                                                            pyramid.GetLevelWidth(level),
-                                                            pyramid.GetLevelHeight(level)));
+      std::unique_ptr<Orthanc::ImageAccessor> result(Allocate(pyramid.GetPixelFormat(), 
+                                                              pyramid.GetLevelWidth(level),
+                                                              pyramid.GetLevelHeight(level)));
 
-      LOG(INFO) << "Rendering a tiled image of size " << result->GetWidth() << "x" << result->GetHeight();
+      LOG(INFO) << "Rendering a tiled image of size "
+                << result->GetWidth() << "x" << result->GetHeight();
 
-      for (unsigned int y = 0; y < result->GetHeight(); y += pyramid.GetTileHeight())
+      const unsigned int width = result->GetWidth();
+      const unsigned int height = result->GetHeight();
+      
+      for (unsigned int y = 0; y < height; y += pyramid.GetTileHeight(level))
       {
-        for (unsigned int x = 0; x < result->GetWidth(); x += pyramid.GetTileWidth())
+        for (unsigned int x = 0; x < width; x += pyramid.GetTileWidth(level))
         {
-          std::auto_ptr<Orthanc::ImageAccessor> tile(pyramid.DecodeTile(level,
-                                                                        x / pyramid.GetTileWidth(),
-                                                                        y / pyramid.GetTileHeight()));
+          std::unique_ptr<Orthanc::ImageAccessor> tile(
+            pyramid.DecodeTile(level,
+                               x / pyramid.GetTileWidth(level),
+                               y / pyramid.GetTileHeight(level)));
           Embed(*result, *tile, x, y);
         }
       }
 
       return result.release();
     }
+
+
+    void CheckConstantTileSize(const ITiledPyramid& source)
+    {
+      if (source.GetLevelCount() == 0)
+      {
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageSize,
+                                        "Input pyramid has no level");
+      }
+      else
+      {
+        for (unsigned int level = 0; level < source.GetLevelCount(); level++)
+        {
+          if (source.GetTileWidth(level) != source.GetTileWidth(0) ||
+              source.GetTileHeight(level) != source.GetTileHeight(0))
+          {
+            throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageSize,
+                                            "The DICOMizer requires that the input pyramid has constant "
+                                            "tile sizes across all its levels, which is not the case");
+          } 
+        }
+      }
+    }
+
+
+    void ConvertJpegYCbCrToRgb(Orthanc::ImageAccessor& image)
+    {
+#if defined(ORTHANC_FRAMEWORK_VERSION_IS_ABOVE) && ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 9, 0)
+      Orthanc::ImageProcessing::ConvertJpegYCbCrToRgb(image);
+#else
+#  if defined(__GNUC__) || defined(__clang__)
+#    warning You are using an old version of the Orthanc framework
+#  endif
+      const unsigned int width = image.GetWidth();
+      const unsigned int height = image.GetHeight();
+      const unsigned int pitch = image.GetPitch();
+      uint8_t* buffer = reinterpret_cast<uint8_t*>(image.GetBuffer());
+        
+      if (image.GetFormat() != Orthanc::PixelFormat_RGB24 ||
+          pitch < 3 * width)
+      {
+        throw Orthanc::OrthancException(Orthanc::ErrorCode_IncompatibleImageFormat);
+      }
+
+      for (unsigned int y = 0; y < height; y++)
+      {
+        uint8_t* p = buffer + y * pitch;
+          
+        for (unsigned int x = 0; x < width; x++, p += 3)
+        {
+          const float Y  = p[0];
+          const float Cb = p[1];
+          const float Cr = p[2];
+
+          const float result[3] = {
+            Y                             + 1.402f    * (Cr - 128.0f),
+            Y - 0.344136f * (Cb - 128.0f) - 0.714136f * (Cr - 128.0f),
+            Y + 1.772f    * (Cb - 128.0f)
+          };
+
+          for (uint8_t i = 0; i < 3 ; i++)
+          {
+            if (result[i] < 0)
+            {
+              p[i] = 0;
+            }
+            else if (result[i] > 255)
+            {
+              p[i] = 255;
+            }
+            else
+            {
+              p[i] = static_cast<uint8_t>(result[i]);
+            }
+          }    
+        }
+      }
+#endif
+    }
   }
 }
