@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,7 +21,7 @@
 
 #pragma once
 
-#include <Core/Images/ImageAccessor.h>
+#include <Images/ImageAccessor.h>
 #include "Enumerations.h"
 #include "Inputs/ITiledPyramid.h"
 
@@ -35,22 +35,16 @@ namespace OrthancWSI
                                      unsigned int width,
                                      unsigned int height);
 
-    void Embed(Orthanc::ImageAccessor& target,
+    void Embed(const Orthanc::ImageAccessor& target,
                const Orthanc::ImageAccessor& source,
                unsigned int x,
                unsigned int y);
 
-    inline void Copy(Orthanc::ImageAccessor& target,
-                     const Orthanc::ImageAccessor& source)
-    {
-      Embed(target, source, 0, 0);
-    }
-
     void Set(Orthanc::ImageAccessor& image,
              uint8_t r,
              uint8_t g,
              uint8_t b);
-
+    
     Orthanc::ImageAccessor* DecodeTile(const std::string& source,
                                        ImageCompression compression);
     
@@ -70,12 +64,11 @@ namespace OrthancWSI
                                ImageCompression targetCompression,
                                uint8_t quality);  // Only for JPEG compression
 
-    Orthanc::ImageAccessor* Halve(const Orthanc::ImageAccessor& source,
-                                  bool smooth);
-
-    Orthanc::ImageAccessor* Clone(const Orthanc::ImageAccessor& accessor);
-
     Orthanc::ImageAccessor* Render(ITiledPyramid& pyramid,
                                    unsigned int level);
+
+    void CheckConstantTileSize(const ITiledPyramid& source);
+
+    void ConvertJpegYCbCrToRgb(Orthanc::ImageAccessor& image /* inplace */);
   }
 }
