@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -24,6 +24,8 @@
 
 #include "../ImageToolbox.h"
 
+#include <Compatibility.h>  // For std::unique_ptr
+
 #include <memory>
 #include <cassert>
 
@@ -59,11 +61,11 @@ namespace OrthancWSI
                                                           unsigned int tileX,
                                                           unsigned int tileY)
   {
-    unsigned int x = tileX * GetTileWidth();
-    unsigned int y = tileY * GetTileHeight();
+    unsigned int x = tileX * GetTileWidth(level);
+    unsigned int y = tileY * GetTileHeight(level);
 
-    std::auto_ptr<Orthanc::ImageAccessor> tile
-      (ImageToolbox::Allocate(GetPixelFormat(), GetTileWidth(), GetTileHeight()));
+    std::unique_ptr<Orthanc::ImageAccessor> tile
+      (ImageToolbox::Allocate(GetPixelFormat(), GetTileWidth(level), GetTileHeight(level)));
 
     if (x >= GetLevelWidth(level) ||
         y >= GetLevelHeight(level))   // (*)
@@ -74,9 +76,9 @@ namespace OrthancWSI
 
     bool fit = true;
     unsigned int regionWidth;
-    if (x + GetTileWidth() <= GetLevelWidth(level))
+    if (x + GetTileWidth(level) <= GetLevelWidth(level))
     {
-      regionWidth = GetTileWidth();
+      regionWidth = GetTileWidth(level);
     }
     else
     {
@@ -86,9 +88,9 @@ namespace OrthancWSI
     }
     
     unsigned int regionHeight;
-    if (y + GetTileHeight() <= GetLevelHeight(level))
+    if (y + GetTileHeight(level) <= GetLevelHeight(level))
     {
-      regionHeight = GetTileHeight();
+      regionHeight = GetTileHeight(level);
     }
     else
     {
@@ -105,7 +107,7 @@ namespace OrthancWSI
     else
     {
       // The tile exceeds the size of image, decode it to a temporary buffer
-      std::auto_ptr<Orthanc::ImageAccessor> cropped
+      std::unique_ptr<Orthanc::ImageAccessor> cropped
         (ImageToolbox::Allocate(GetPixelFormat(), regionWidth, regionHeight));
       ReadRegion(*cropped, level, x, y);
 
