@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,8 +23,11 @@
 #include "DicomPyramid.h"
 
 #include "../DicomToolbox.h"
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
+
+#include <Compatibility.h>
+#include <Logging.h>
+#include <OrthancException.h>
+#include <Toolbox.h>
 
 #include <algorithm>
 #include <cassert>
@@ -65,7 +68,7 @@ namespace OrthancWSI
                                        bool useCache)
   {
     Json::Value series;
-    OrthancPlugins::IOrthancConnection::RestApiGet(series, orthanc_, "/series/" + seriesId);
+    OrthancStone::IOrthancConnection::RestApiGet(series, orthanc_, "/series/" + seriesId);
 
     if (series.type() != Json::objectValue ||
         !series.isMember("Instances") ||
@@ -84,15 +87,26 @@ namespace OrthancWSI
         throw Orthanc::OrthancException(Orthanc::ErrorCode_NetworkProtocol);
       }
 
-      std::string instance = instances[i].asString();
+      std::string instanceId = instances[i].asString();
 
       try
       {
-        instances_.push_back(new DicomPyramidInstance(orthanc_, instance, useCache));
+        std::unique_ptr<DicomPyramidInstance> instance(new DicomPyramidInstance(orthanc_, instanceId, useCache));
+
+        std::vector<std::string> tokens;
+        Orthanc::Toolbox::TokenizeString(tokens, instance->GetImageType(), '\\');
+
+        // Don't consider the thumbnail and overview as part of the DICOM pyramid (new in 1.0)
+        if (tokens.size() < 2 ||
+            (tokens[2] != "THUMBNAIL" &&
+             tokens[2] != "OVERVIEW"))
+        {
+          instances_.push_back(instance.release());
+        }        
       }
       catch (Orthanc::OrthancException&)
       {
-        LOG(ERROR) << "Skipping a DICOM instance that is not part of a whole-slide image: " << instance;
+        LOG(ERROR) << "Skipping a DICOM instance that is not part of a whole-slide image: " << instanceId;
       }
     }
   }
@@ -113,8 +127,6 @@ namespace OrthancWSI
       const DicomPyramidInstance& b = *instances_[i];
 
       if (a.GetPixelFormat() != b.GetPixelFormat() ||
-          a.GetTileWidth() != b.GetTileWidth() ||
-          a.GetTileHeight() != b.GetTileHeight() ||
           a.GetTotalWidth() < b.GetTotalWidth() ||
           a.GetTotalHeight() < b.GetTotalHeight())            
       {
@@ -139,7 +151,7 @@ namespace OrthancWSI
   }
 
 
-  DicomPyramid::DicomPyramid(OrthancPlugins::IOrthancConnection& orthanc,
+  DicomPyramid::DicomPyramid(OrthancStone::IOrthancConnection& orthanc,
                              const std::string& seriesId,
                              bool useCache) :
     orthanc_(orthanc),
@@ -190,17 +202,17 @@ namespace OrthancWSI
   }
 
 
-  unsigned int DicomPyramid::GetTileWidth() const
+  unsigned int DicomPyramid::GetTileWidth(unsigned int level) const
   {
-    assert(!levels_.empty() && levels_[0] != NULL);
-    return levels_[0]->GetTileWidth();
+    CheckLevel(level);
+    return levels_[level]->GetTileWidth();
   }
 
 
-  unsigned int DicomPyramid::GetTileHeight() const
+  unsigned int DicomPyramid::GetTileHeight(unsigned int level) const
   {
-    assert(!levels_.empty() && levels_[0] != NULL);
-    return levels_[0]->GetTileHeight();
+    CheckLevel(level);
+    return levels_[level]->GetTileHeight();
   }
 
 
