@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -32,10 +32,10 @@ namespace OrthancWSI
   private:
     struct Comparator;
 
-    OrthancPlugins::IOrthancConnection&  orthanc_;
-    std::string                          seriesId_;
-    std::vector<DicomPyramidInstance*>   instances_;
-    std::vector<DicomPyramidLevel*>      levels_;
+    OrthancStone::IOrthancConnection&   orthanc_;
+    std::string                         seriesId_;
+    std::vector<DicomPyramidInstance*>  instances_;
+    std::vector<DicomPyramidLevel*>     levels_;
 
     void Clear();
 
@@ -47,7 +47,7 @@ namespace OrthancWSI
     void CheckLevel(size_t level) const;
 
   public:
-    DicomPyramid(OrthancPlugins::IOrthancConnection& orthanc,
+    DicomPyramid(OrthancStone::IOrthancConnection& orthanc,
                  const std::string& seriesId,
                  bool useCache);
 
@@ -61,27 +61,27 @@ namespace OrthancWSI
       return seriesId_;
     }
 
-    virtual unsigned int GetLevelCount() const
+    virtual unsigned int GetLevelCount() const ORTHANC_OVERRIDE
     {
       return levels_.size();
     }
 
-    virtual unsigned int GetLevelWidth(unsigned int level) const;
+    virtual unsigned int GetLevelWidth(unsigned int level) const ORTHANC_OVERRIDE;
 
-    virtual unsigned int GetLevelHeight(unsigned int level) const;
+    virtual unsigned int GetLevelHeight(unsigned int level) const ORTHANC_OVERRIDE;
 
-    virtual unsigned int GetTileWidth() const;
+    virtual unsigned int GetTileWidth(unsigned int level) const ORTHANC_OVERRIDE;
 
-    virtual unsigned int GetTileHeight() const;
+    virtual unsigned int GetTileHeight(unsigned int level) const ORTHANC_OVERRIDE;
 
     virtual bool ReadRawTile(std::string& tile,
                              ImageCompression& compression,
                              unsigned int level,
                              unsigned int tileX,
-                             unsigned int tileY);
+                             unsigned int tileY) ORTHANC_OVERRIDE;
 
-    virtual Orthanc::PixelFormat GetPixelFormat() const;
+    virtual Orthanc::PixelFormat GetPixelFormat() const ORTHANC_OVERRIDE;
 
-    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const;
+    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const ORTHANC_OVERRIDE;
   };
 }
