@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,7 +22,7 @@
 #pragma once
 
 #include "../Enumerations.h"
-#include <Plugins/Samples/Common/IOrthancConnection.h>
+#include "../../Resources/Orthanc/Stone/IOrthancConnection.h"
 
 #include <boost/noncopyable.hpp>
 #include <vector>
@@ -34,24 +34,25 @@ namespace OrthancWSI
   private:
     typedef std::pair<unsigned int, unsigned int>  FrameLocation;
 
-    std::string                 instanceId_;
-    bool                        hasCompression_;
-    ImageCompression            compression_;
-    Orthanc::PixelFormat        format_;
-    unsigned int                tileWidth_;
-    unsigned int                tileHeight_;
-    unsigned int                totalWidth_;
-    unsigned int                totalHeight_;
-    std::vector<FrameLocation>  frames_;
+    std::string                         instanceId_;
+    bool                                hasCompression_;
+    ImageCompression                    compression_;
+    Orthanc::PixelFormat                format_;
+    unsigned int                        tileWidth_;
+    unsigned int                        tileHeight_;
+    unsigned int                        totalWidth_;
+    unsigned int                        totalHeight_;
+    std::vector<FrameLocation>          frames_;
     Orthanc::PhotometricInterpretation  photometric_;
+    std::string                         imageType_;
 
-    void Load(OrthancPlugins::IOrthancConnection&  orthanc,
+    void Load(OrthancStone::IOrthancConnection&  orthanc,
               const std::string& instanceId);
 
     void Deserialize(const std::string& content);
 
   public:
-    DicomPyramidInstance(OrthancPlugins::IOrthancConnection&  orthanc,
+    DicomPyramidInstance(OrthancStone::IOrthancConnection&  orthanc,
                          const std::string& instanceId,
                          bool useCache);
 
@@ -60,7 +61,7 @@ namespace OrthancWSI
       return instanceId_;
     }
 
-    ImageCompression GetImageCompression(OrthancPlugins::IOrthancConnection& orthanc);
+    ImageCompression GetImageCompression(OrthancStone::IOrthancConnection& orthanc);
 
     Orthanc::PixelFormat GetPixelFormat() const
     {
@@ -97,6 +98,11 @@ namespace OrthancWSI
       return frames_.size();
     }
 
+    const std::string& GetImageType() const
+    {
+      return imageType_;
+    }
+
     unsigned int GetFrameLocationX(size_t frame) const;
 
     unsigned int GetFrameLocationY(size_t frame) const;
