@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,7 +23,8 @@
 
 #include "../Enumerations.h"
 
-#include <Core/Images/ImageAccessor.h>
+#include <Compatibility.h>
+#include <Images/ImageAccessor.h>
 
 #include <boost/noncopyable.hpp>
 #include <string>
@@ -48,9 +49,9 @@ namespace OrthancWSI
 
     virtual unsigned int GetLevelHeight(unsigned int level) const = 0;
 
-    virtual unsigned int GetTileWidth() const = 0;
+    virtual unsigned int GetTileWidth(unsigned int level) const = 0;
 
-    virtual unsigned int GetTileHeight() const = 0;
+    virtual unsigned int GetTileHeight(unsigned int level) const = 0;
 
     virtual bool ReadRawTile(std::string& tile,
                              ImageCompression& compression,
