@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,15 +22,16 @@
 #include "../PrecompiledHeadersWSI.h"
 #include "OpenSlideLibrary.h"
 
-#include <Core/Logging.h>
-#include <Core/Images/Image.h>
-#include <Core/OrthancException.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <Images/Image.h>
+#include <OrthancException.h>
 
 #include <memory>
 
 namespace OrthancWSI
 {
-  static std::auto_ptr<OpenSlideLibrary>  globalLibrary_;
+  static std::unique_ptr<OpenSlideLibrary>  globalLibrary_;
 
 
   OpenSlideLibrary::OpenSlideLibrary(const std::string& path) :
@@ -194,7 +195,7 @@ namespace OrthancWSI
     CheckLevel(level);
 
     // Create a new image, with minimal pitch so as to be compatible with OpenSlide API
-    std::auto_ptr<Orthanc::ImageAccessor> region(new Orthanc::Image(Orthanc::PixelFormat_BGRA32, width, height, true));
+    std::unique_ptr<Orthanc::ImageAccessor> region(new Orthanc::Image(Orthanc::PixelFormat_BGRA32, width, height, true));
 
     if (region->GetWidth() != 0 &&
         region->GetHeight() != 0)
