@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -37,44 +37,44 @@ namespace OrthancWSI
     virtual void ReadRegion(Orthanc::ImageAccessor& target,
                             unsigned int level,
                             unsigned int x,
-                            unsigned int y);
+                            unsigned int y) ORTHANC_OVERRIDE;
 
   public:
     OpenSlidePyramid(const std::string& path,
                      unsigned int tileWidth,
                      unsigned int tileHeight);
 
-    virtual unsigned int GetTileWidth() const
+    virtual unsigned int GetTileWidth(unsigned int level) const ORTHANC_OVERRIDE
     {
       return tileWidth_;
     }
 
-    virtual unsigned int GetTileHeight() const
+    virtual unsigned int GetTileHeight(unsigned int level) const ORTHANC_OVERRIDE
     {
       return tileHeight_;
     }
 
-    virtual unsigned int GetLevelCount() const
+    virtual unsigned int GetLevelCount() const ORTHANC_OVERRIDE
     {
       return image_.GetLevelCount();
     }
 
-    virtual unsigned int GetLevelWidth(unsigned int level) const
+    virtual unsigned int GetLevelWidth(unsigned int level) const ORTHANC_OVERRIDE
     {
       return image_.GetLevelWidth(level);
     }
 
-    virtual unsigned int GetLevelHeight(unsigned int level) const
+    virtual unsigned int GetLevelHeight(unsigned int level) const ORTHANC_OVERRIDE
     {
       return image_.GetLevelHeight(level);
     }
 
-    virtual Orthanc::PixelFormat GetPixelFormat() const
+    virtual Orthanc::PixelFormat GetPixelFormat() const ORTHANC_OVERRIDE
     {
       return Orthanc::PixelFormat_RGB24;
     }
 
-    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const
+    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const ORTHANC_OVERRIDE
     {
       return Orthanc::PhotometricInterpretation_RGB;
     }
