@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,7 +23,8 @@
 #include "SingleLevelDecodedPyramid.h"
 #include "../ImageToolbox.h"
 
-#include <Core/OrthancException.h>
+#include <OrthancException.h>
+#include <Images/ImageProcessing.h>
 
 namespace OrthancWSI
 {
@@ -34,7 +35,7 @@ namespace OrthancWSI
   {
     Orthanc::ImageAccessor region;
     image_.GetRegion(region, x, y, target.GetWidth(), target.GetHeight());
-    ImageToolbox::Copy(target, region);
+    Orthanc::ImageProcessing::Copy(target, region);
   }
 
 
