@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -40,32 +40,32 @@ namespace OrthancWSI
 
     virtual ~TiledPyramidStatistics();
 
-    virtual unsigned int GetLevelCount() const
+    virtual unsigned int GetLevelCount() const ORTHANC_OVERRIDE
     {
       return source_.GetLevelCount();
     }
 
-    virtual unsigned int GetLevelWidth(unsigned int level)  const
+    virtual unsigned int GetLevelWidth(unsigned int level)  const ORTHANC_OVERRIDE
     {
       return source_.GetLevelWidth(level);
     }
 
-    virtual unsigned int GetLevelHeight(unsigned int level) const
+    virtual unsigned int GetLevelHeight(unsigned int level) const ORTHANC_OVERRIDE
     {
       return source_.GetLevelHeight(level);
     }
 
-    virtual unsigned int GetTileWidth() const
+    virtual unsigned int GetTileWidth(unsigned int level) const ORTHANC_OVERRIDE
     {
-      return source_.GetTileWidth();
+      return source_.GetTileWidth(level);
     }
     
-    virtual unsigned int GetTileHeight() const
+    virtual unsigned int GetTileHeight(unsigned int level) const ORTHANC_OVERRIDE
     {
-      return source_.GetTileHeight();
+      return source_.GetTileHeight(level);
     }
 
-    virtual Orthanc::PixelFormat GetPixelFormat() const
+    virtual Orthanc::PixelFormat GetPixelFormat() const ORTHANC_OVERRIDE
     {
       return source_.GetPixelFormat();
     }
@@ -74,13 +74,13 @@ namespace OrthancWSI
                              ImageCompression& compression,
                              unsigned int level,
                              unsigned int tileX,
-                             unsigned int tileY);
+                             unsigned int tileY) ORTHANC_OVERRIDE;
 
     virtual Orthanc::ImageAccessor* DecodeTile(unsigned int level,
                                                unsigned int tileX,
-                                               unsigned int tileY);
+                                               unsigned int tileY) ORTHANC_OVERRIDE;
 
-    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const
+    virtual Orthanc::PhotometricInterpretation GetPhotometricInterpretation() const ORTHANC_OVERRIDE
     {
       return source_.GetPhotometricInterpretation();
     }
