@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,7 +21,9 @@
 
 #pragma once
 
-#include <Core/Images/Image.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Images/Image.h>
+
 #include <memory>
 
 namespace OrthancWSI
@@ -36,7 +38,7 @@ namespace OrthancWSI
   class Jpeg2000Reader : public Orthanc::ImageAccessor
   {
   private:
-    std::auto_ptr<Orthanc::ImageAccessor> image_;
+    std::unique_ptr<Orthanc::ImageAccessor> image_;
 
   public:
     void ReadFromFile(const std::string& filename);
