@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,8 +21,9 @@
 
 #include "BagOfTasksProcessor.h"
 
-#include <Core/Logging.h>
-#include <Core/OrthancException.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <OrthancException.h>
 
 #include <stdio.h>
 
@@ -32,7 +33,7 @@ namespace Orthanc
   {
   private:
     uint64_t                 bag_;
-    std::auto_ptr<ICommand>  command_;
+    std::unique_ptr<ICommand>  command_;
 
   public:
     Task(uint64_t  bag,
@@ -90,7 +91,7 @@ namespace Orthanc
   {
     while (that->continue_)
     {
-      std::auto_ptr<IDynamicObject> obj(that->queue_.Dequeue(100));
+      std::unique_ptr<IDynamicObject> obj(that->queue_.Dequeue(100));
       if (obj.get() != NULL)
       {
         Task& task = *dynamic_cast<Task*>(obj.get());
