@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -69,9 +69,9 @@ namespace OrthancWSI
     virtual void WriteRawTileInternal(const std::string& tile,
                                       const Level& level,
                                       unsigned int tileX,
-                                      unsigned int tileY);
+                                      unsigned int tileY) ORTHANC_OVERRIDE;
         
-    virtual void AddLevelInternal(const Level& level);
+    virtual void AddLevelInternal(const Level& level) ORTHANC_OVERRIDE;
 
 
   public:
@@ -84,6 +84,6 @@ namespace OrthancWSI
 
     virtual ~HierarchicalTiffWriter();
 
-    virtual void Flush();
+    virtual void Flush() ORTHANC_OVERRIDE;
   };
 }
