@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,10 +22,13 @@
 #include "../PrecompiledHeadersWSI.h"
 #include "MultiframeDicomWriter.h"
 
-#include <Core/OrthancException.h>
-#include <Core/Logging.h>
 #include "../DicomToolbox.h"
 
+#include <Compatibility.h>  // For std::unique_ptr
+#include <DicomParsing/FromDcmtkBridge.h>
+#include <Logging.h>
+#include <OrthancException.h>
+
 #include <dcmtk/dcmdata/dcuid.h>
 #include <dcmtk/dcmdata/dcdeftag.h>
 #include <dcmtk/dcmdata/dcostrmb.h>
@@ -96,6 +99,9 @@ namespace OrthancWSI
       offsetList_.reset(new DcmOffsetList);
     }
 
+    firstFrameInInstance_ += framesCount_;
+    countInstances_ ++;
+
     writtenSize_ = 0;
     framesCount_ = 0;
   }
@@ -115,7 +121,7 @@ namespace OrthancWSI
       throw Orthanc::OrthancException(Orthanc::ErrorCode_NotEnoughMemory);
     }
 
-    std::auto_ptr<DcmPixelData> pixels(new DcmPixelData(DCM_PixelData));
+    std::unique_ptr<DcmPixelData> pixels(new DcmPixelData(DCM_PixelData));
 
     uint8_t* target = NULL;
     if (!pixels->createUint8Array(pixelData.size(), target).good())
@@ -148,10 +154,15 @@ namespace OrthancWSI
                                                unsigned int height,
                                                unsigned int tileWidth,
                                                unsigned int tileHeight,
-                                               Orthanc::PhotometricInterpretation photometric) :
+                                               Orthanc::PhotometricInterpretation photometric,
+                                               bool isConcatenation) :
     compression_(compression),
+    framesCount_(0),
     width_(width),
-    height_(height)
+    height_(height),
+    isConcatenation_(isConcatenation),
+    countInstances_(0),
+    firstFrameInInstance_(0)
   {
     switch (compression)
     {
@@ -206,6 +217,28 @@ namespace OrthancWSI
         throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
     }
 
+    if (isConcatenation)
+    {
+      /**
+       * Generate a shared SOP Instance UID that corresponds to the
+       * main instance containing all the instances. This main
+       * instance is purely "virtual", as it is never generated.
+       * https://bugs.orthanc-server.com/show_bug.cgi?id=145
+       * http://dicom.nema.org/medical/dicom/2020d/output/chtml/part03/figures/PS3.3_C.7.6.16-1a.svg
+       **/
+      DicomToolbox::SetStringTag(sharedTags_, DCM_SOPInstanceUIDOfConcatenationSource,
+                                 Orthanc::FromDcmtkBridge::GenerateUniqueIdentifier(Orthanc::ResourceType_Instance));
+
+      /**
+       * Similarly, we generate one random UID to identify the
+       * concatenation. As we never generate two different
+       * concatenations of the "main" instance, this UID is shared by
+       * all the instances of the concatenation.
+       **/
+      DicomToolbox::SetStringTag(sharedTags_, DCM_ConcatenationUID,
+                                 Orthanc::FromDcmtkBridge::GenerateUniqueIdentifier(Orthanc::ResourceType_Instance));
+    }
+
     ResetImage();
   }
 
@@ -214,7 +247,7 @@ namespace OrthancWSI
                                        DcmItem* functionalGroup)   // This takes the ownership
   {
     // Free the functional group on error
-    std::auto_ptr<DcmItem> functionalGroupRaii(functionalGroup);
+    std::unique_ptr<DcmItem> functionalGroupRaii(functionalGroup);
 
     if (compression_ == ImageCompression_None)
     {
@@ -257,23 +290,27 @@ namespace OrthancWSI
       throw Orthanc::OrthancException(Orthanc::ErrorCode_ParameterOutOfRange);
     }
 
-    std::string tmp = boost::lexical_cast<std::string>(instanceNumber);
-
-    std::auto_ptr<DcmFileFormat> dicom(new DcmFileFormat);
-
-    char uid[100];
-    dcmGenerateUniqueIdentifier(uid, SITE_INSTANCE_UID_ROOT);
+    std::unique_ptr<DcmFileFormat> dicom(new DcmFileFormat);
 
+    const std::string uid = Orthanc::FromDcmtkBridge::GenerateUniqueIdentifier(Orthanc::ResourceType_Instance);
+    
     if (!dicom->getDataset()->copyFrom(sharedTags_).good() ||
         !dicom->getDataset()->insert(perFrameFunctionalGroups_.release(), false, false).good() ||
-        !dicom->getDataset()->putAndInsertString(DCM_SOPInstanceUID, uid).good() ||
-        !dicom->getDataset()->putAndInsertString(DCM_InstanceNumber, tmp.c_str()).good())
+        !dicom->getDataset()->putAndInsertString(DCM_SOPInstanceUID, uid.c_str()).good())
     {
       throw Orthanc::OrthancException(Orthanc::ErrorCode_InternalError);
     }
 
+    // The two tags below have "IS" (integer string) value representation
+    DicomToolbox::SetStringTag(*dicom->getDataset(), DCM_InstanceNumber, boost::lexical_cast<std::string>(instanceNumber));
     DicomToolbox::SetStringTag(*dicom->getDataset(), DCM_NumberOfFrames, boost::lexical_cast<std::string>(framesCount_));
 
+    if (isConcatenation_)
+    {
+      DicomToolbox::SetUint32Tag(*dicom->getDataset(), DCM_ConcatenationFrameOffsetNumber, firstFrameInInstance_);
+      DicomToolbox::SetUint16Tag(*dicom->getDataset(), DCM_InConcatenationNumber, countInstances_);
+    }
+
     switch (compression_)
     {
       case ImageCompression_None:
