@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,7 +22,9 @@
 #pragma once
 
 #include "../Enumerations.h"
-#include <Core/ChunkedBuffer.h>
+
+#include <Compatibility.h>  // For std::unique_ptr
+#include <ChunkedBuffer.h>
 
 #include <boost/noncopyable.hpp>
 #include <memory>
@@ -47,11 +49,15 @@ namespace OrthancWSI
     unsigned int      height_;
 
     Orthanc::ChunkedBuffer             uncompressedPixelData_;
-    std::auto_ptr<DcmSequenceOfItems>  perFrameFunctionalGroups_;
-    std::auto_ptr<DcmPixelSequence>    compressedPixelSequence_;
+    std::unique_ptr<DcmSequenceOfItems>  perFrameFunctionalGroups_;
+    std::unique_ptr<DcmPixelSequence>    compressedPixelSequence_;
     DcmPixelItem*                      offsetTable_;
-    std::auto_ptr<DcmOffsetList>       offsetList_;
+    std::unique_ptr<DcmOffsetList>       offsetList_;
 
+    bool             isConcatenation_;
+    unsigned int     countInstances_;
+    unsigned int     firstFrameInInstance_;
+    
     void ResetImage();
 
     void InjectUncompressedPixelData(DcmFileFormat& dicom);
@@ -64,7 +70,8 @@ namespace OrthancWSI
                           unsigned int height,
                           unsigned int tileWidth,
                           unsigned int tileHeight,
-                          Orthanc::PhotometricInterpretation photometric);
+                          Orthanc::PhotometricInterpretation photometric,
+                          bool isConcatenation);
 
     void AddFrame(const std::string& frame,
                   DcmItem* functionalGroup);   // This takes the ownership
