@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -37,40 +37,40 @@ namespace OrthancWSI
                            unsigned int upperLevelIndex,
                            Orthanc::PhotometricInterpretation photometric);
 
-    virtual unsigned int GetLevelCount() const
+    virtual unsigned int GetLevelCount() const ORTHANC_OVERRIDE
     {
       return upperLevelIndex_ + 1;
     }
 
-    virtual Orthanc::PixelFormat GetPixelFormat() const 
+    virtual Orthanc::PixelFormat GetPixelFormat() const ORTHANC_OVERRIDE
     {
       return lowerLevels_.GetPixelFormat();
     }
 
-    virtual unsigned int GetTileWidth() const
+    virtual unsigned int GetTileWidth() const ORTHANC_OVERRIDE
     {
       return lowerLevels_.GetTileWidth();
     }
 
-    virtual unsigned int GetTileHeight() const 
+    virtual unsigned int GetTileHeight() const ORTHANC_OVERRIDE
     {
       return lowerLevels_.GetTileHeight();
     }
 
-    virtual unsigned int GetCountTilesX(unsigned int level) const;
+    virtual unsigned int GetCountTilesX(unsigned int level) const ORTHANC_OVERRIDE;
 
-    virtual unsigned int GetCountTilesY(unsigned int level) const;
+    virtual unsigned int GetCountTilesY(unsigned int level) const ORTHANC_OVERRIDE;
 
     virtual void WriteRawTile(const std::string& tile,
                               ImageCompression compression,
                               unsigned int level,
                               unsigned int x,
-                              unsigned int y);
+                              unsigned int y) ORTHANC_OVERRIDE;
 
     virtual void EncodeTile(const Orthanc::ImageAccessor& tile,
                             unsigned int level,
                             unsigned int x, 
-                            unsigned int y);
+                            unsigned int y) ORTHANC_OVERRIDE;
 
     InMemoryTiledImage& GetUpperLevel()
     {
