@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,14 +23,16 @@
 #include "OrthancTarget.h"
 
 #include "../DicomToolbox.h"
-#include <Core/OrthancException.h>
-#include <Core/Logging.h>
-#include <Plugins/Samples/Common/OrthancHttpConnection.h>
+#include "../../Resources/Orthanc/Stone/OrthancHttpConnection.h"
+
+#include <OrthancException.h>
+#include <Logging.h>
+
 
 namespace OrthancWSI
 {
   OrthancTarget::OrthancTarget(const Orthanc::WebServiceParameters& parameters) :
-    orthanc_(new OrthancPlugins::OrthancHttpConnection(parameters)),
+    orthanc_(new OrthancStone::OrthancHttpConnection(parameters)),
     first_(true)
   {
   }
@@ -39,7 +41,7 @@ namespace OrthancWSI
   void OrthancTarget::Write(const std::string& file)
   {
     Json::Value result;
-    OrthancPlugins::IOrthancConnection::RestApiPost(result, *orthanc_, "/instances", file);
+    OrthancStone::IOrthancConnection::RestApiPost(result, *orthanc_, "/instances", file);
 
     if (result.type() != Json::objectValue ||
         !result.isMember("ID") ||
@@ -53,7 +55,7 @@ namespace OrthancWSI
     if (first_)
     {
       Json::Value instance;
-      OrthancPlugins::IOrthancConnection::RestApiGet(instance, *orthanc_, "/instances/" + instanceId);
+      OrthancStone::IOrthancConnection::RestApiGet(instance, *orthanc_, "/instances/" + instanceId);
 
       if (instance.type() != Json::objectValue ||
           !instance.isMember("ParentSeries") ||
