@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,8 +22,10 @@
 #pragma once
 
 #include "IFileTarget.h"
-#include <Core/WebServiceParameters.h>
-#include <Plugins/Samples/Common/IOrthancConnection.h>
+#include "../../Resources/Orthanc/Stone/IOrthancConnection.h"
+
+#include <Compatibility.h>  // For std::unique_ptr
+#include <WebServiceParameters.h>
 
 #include <memory>
 
@@ -32,18 +34,18 @@ namespace OrthancWSI
   class OrthancTarget : public IFileTarget
   {
   private:
-    std::auto_ptr<OrthancPlugins::IOrthancConnection>  orthanc_;
+    std::unique_ptr<OrthancStone::IOrthancConnection>  orthanc_;
     bool  first_;
 
   public:
     explicit OrthancTarget(const Orthanc::WebServiceParameters& parameters);
 
-    explicit OrthancTarget(OrthancPlugins::IOrthancConnection* orthanc) :   // Takes ownership
+    explicit OrthancTarget(OrthancStone::IOrthancConnection* orthanc) :   // Takes ownership
       orthanc_(orthanc),
       first_(true)
     {
     }
 
-    virtual void Write(const std::string& file);
+    virtual void Write(const std::string& file) ORTHANC_OVERRIDE;
   };
 }
