@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -22,6 +22,8 @@
 #include "../Framework/PrecompiledHeadersWSI.h"
 #include "DicomPyramidCache.h"
 
+#include <Compatibility.h>  // For std::unique_ptr
+
 #include <cassert>
 
 namespace OrthancWSI
@@ -64,7 +66,7 @@ namespace OrthancWSI
     // time-consuming operation, we don't want it to block other clients)
     lock.unlock();
 
-    std::auto_ptr<DicomPyramid> pyramid
+    std::unique_ptr<DicomPyramid> pyramid
       (new DicomPyramid(orthanc_, seriesId, true /* use metadata cache */));
 
     {
@@ -109,7 +111,7 @@ namespace OrthancWSI
   }
 
 
-  DicomPyramidCache::DicomPyramidCache(OrthancPlugins::IOrthancConnection& orthanc,
+  DicomPyramidCache::DicomPyramidCache(OrthancStone::IOrthancConnection& orthanc,
                                        size_t maxSize) :
     orthanc_(orthanc),
     maxSize_(maxSize)
@@ -138,7 +140,7 @@ namespace OrthancWSI
 
     if (cache_.Contains(seriesId))
     {
-      std::auto_ptr<DicomPyramid> pyramid(cache_.Invalidate(seriesId));
+      std::unique_ptr<DicomPyramid> pyramid(cache_.Invalidate(seriesId));
 
       if (pyramid.get() == NULL)
       {
