@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -23,7 +23,7 @@
 
 #include "../Framework/Inputs/DicomPyramid.h"
 
-#include <Core/Cache/LeastRecentlyUsedIndex.h>
+#include <Cache/LeastRecentlyUsedIndex.h>
 
 #include <boost/thread/mutex.hpp>
 
@@ -34,10 +34,10 @@ namespace OrthancWSI
   private:
     typedef Orthanc::LeastRecentlyUsedIndex<std::string, DicomPyramid*>  Cache;
 
-    boost::mutex                         mutex_;
-    OrthancPlugins::IOrthancConnection&  orthanc_;
-    size_t                               maxSize_;
-    Cache                                cache_;
+    boost::mutex                       mutex_;
+    OrthancStone::IOrthancConnection&  orthanc_;
+    size_t                             maxSize_;
+    Cache                              cache_;
 
 
     DicomPyramid* GetCachedPyramid(const std::string& seriesId);
@@ -46,7 +46,7 @@ namespace OrthancWSI
                              boost::mutex::scoped_lock& lock);
 
   public:
-    DicomPyramidCache(OrthancPlugins::IOrthancConnection& orthanc,
+    DicomPyramidCache(OrthancStone::IOrthancConnection& orthanc,
                       size_t maxSize);
 
     ~DicomPyramidCache();
