@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -21,25 +21,28 @@
 
 #include "../Framework/PrecompiledHeadersWSI.h"
 
-#include "DicomPyramidCache.h"
+#include "../Framework/ImageToolbox.h"
 #include "../Framework/Jpeg2000Reader.h"
+#include "DicomPyramidCache.h"
+#include "OrthancPluginConnection.h"
 
-#include <Core/Logging.h>
-#include <Core/Images/ImageProcessing.h>
-#include <Core/Images/PngWriter.h>
-#include <Core/MultiThreading/Semaphore.h>
-#include <Core/OrthancException.h>
-#include <Core/SystemToolbox.h>
-#include <Plugins/Samples/Common/OrthancPluginCppWrapper.h>
-#include <Plugins/Samples/Common/OrthancPluginConnection.h>
+#include <Compatibility.h>  // For std::unique_ptr
+#include <Logging.h>
+#include <Images/ImageProcessing.h>
+#include <Images/PngWriter.h>
+#include <MultiThreading/Semaphore.h>
+#include <OrthancException.h>
+#include <SystemToolbox.h>
+
+#include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 
 #include <EmbeddedResources.h>
 
 #include <cassert>
 
-std::auto_ptr<OrthancPlugins::OrthancPluginConnection>  orthanc_;
-std::auto_ptr<OrthancWSI::DicomPyramidCache>            cache_;
-std::auto_ptr<Orthanc::Semaphore>                       transcoderSemaphore_;
+std::unique_ptr<OrthancWSI::OrthancPluginConnection>  orthanc_;
+std::unique_ptr<OrthancWSI::DicomPyramidCache>        cache_;
+std::unique_ptr<Orthanc::Semaphore>                   transcoderSemaphore_;
 
 
 static void AnswerSparseTile(OrthancPluginRestOutput* output,
@@ -84,19 +87,20 @@ void ServePyramid(OrthancPluginRestOutput* output,
 
   OrthancWSI::DicomPyramidCache::Locker locker(*cache_, seriesId);
 
-  unsigned int tileWidth = locker.GetPyramid().GetTileWidth();
-  unsigned int tileHeight = locker.GetPyramid().GetTileHeight();
   unsigned int totalWidth = locker.GetPyramid().GetLevelWidth(0);
   unsigned int totalHeight = locker.GetPyramid().GetLevelHeight(0);
 
   Json::Value sizes = Json::arrayValue;
   Json::Value resolutions = Json::arrayValue;
   Json::Value tilesCount = Json::arrayValue;
+  Json::Value tilesSizes = Json::arrayValue;
   for (unsigned int i = 0; i < locker.GetPyramid().GetLevelCount(); i++)
   {
-    unsigned int levelWidth = locker.GetPyramid().GetLevelWidth(i);
-    unsigned int levelHeight = locker.GetPyramid().GetLevelHeight(i);
-
+    const unsigned int levelWidth = locker.GetPyramid().GetLevelWidth(i);
+    const unsigned int levelHeight = locker.GetPyramid().GetLevelHeight(i);
+    const unsigned int tileWidth = locker.GetPyramid().GetTileWidth(i);
+    const unsigned int tileHeight = locker.GetPyramid().GetTileHeight(i);
+    
     resolutions.append(static_cast<float>(totalWidth) / static_cast<float>(levelWidth));
     
     Json::Value s = Json::arrayValue;
@@ -108,15 +112,19 @@ void ServePyramid(OrthancPluginRestOutput* output,
     s.append(OrthancWSI::CeilingDivision(levelWidth, tileWidth));
     s.append(OrthancWSI::CeilingDivision(levelHeight, tileHeight));
     tilesCount.append(s);
+
+    s = Json::arrayValue;
+    s.append(tileWidth);
+    s.append(tileHeight);
+    tilesSizes.append(s);
   }
 
   Json::Value result;
   result["ID"] = seriesId;
   result["Resolutions"] = resolutions;
   result["Sizes"] = sizes;
-  result["TileHeight"] = tileHeight;
-  result["TileWidth"] = tileWidth;
   result["TilesCount"] = tilesCount;
+  result["TilesSizes"] = tilesSizes;
   result["TotalHeight"] = totalHeight;
   result["TotalWidth"] = totalWidth;
 
@@ -147,6 +155,7 @@ void ServeTile(OrthancPluginRestOutput* output,
 
   // Retrieve the raw tile from the WSI pyramid
   OrthancWSI::ImageCompression compression;
+  Orthanc::PhotometricInterpretation photometric;
   Orthanc::PixelFormat format;
   std::string tile;
   unsigned int tileWidth, tileHeight;
@@ -155,8 +164,9 @@ void ServeTile(OrthancPluginRestOutput* output,
     OrthancWSI::DicomPyramidCache::Locker locker(*cache_, seriesId);
 
     format = locker.GetPyramid().GetPixelFormat();
-    tileWidth = locker.GetPyramid().GetTileWidth();
-    tileHeight = locker.GetPyramid().GetTileHeight();
+    tileWidth = locker.GetPyramid().GetTileWidth(level);
+    tileHeight = locker.GetPyramid().GetTileHeight(level);
+    photometric = locker.GetPyramid().GetPhotometricInterpretation();
 
     if (!locker.GetPyramid().ReadRawTile(tile, compression, 
                                          static_cast<unsigned int>(level),
@@ -182,7 +192,7 @@ void ServeTile(OrthancPluginRestOutput* output,
 
   // The tile does not come from a DICOM-JPEG instance, we need to
   // decompress the raw tile
-  std::auto_ptr<Orthanc::ImageAccessor> decoded;
+  std::unique_ptr<Orthanc::ImageAccessor> decoded;
 
   Orthanc::Semaphore::Locker locker(*transcoderSemaphore_);
 
@@ -191,6 +201,12 @@ void ServeTile(OrthancPluginRestOutput* output,
     case OrthancWSI::ImageCompression_Jpeg2000:
       decoded.reset(new OrthancWSI::Jpeg2000Reader);
       dynamic_cast<OrthancWSI::Jpeg2000Reader&>(*decoded).ReadFromMemory(tile);
+
+      if (photometric == Orthanc::PhotometricInterpretation_YBR_ICT)
+      {
+        OrthancWSI::ImageToolbox::ConvertJpegYCbCrToRgb(*decoded);
+      }
+      
       break;
 
     case OrthancWSI::ImageCompression_None:
@@ -217,7 +233,7 @@ void ServeTile(OrthancPluginRestOutput* output,
 
   std::string png;
   Orthanc::PngWriter writer;
-  writer.WriteToMemory(png, *decoded);
+  Orthanc::IImageWriter::WriteToMemory(writer, png, *decoded);
 
   OrthancPluginAnswerBuffer(OrthancPlugins::GetGlobalContext(), output, png.c_str(), png.size(), "image/png");
 }
@@ -310,7 +326,11 @@ extern "C"
       return -1;
     }
 
+#if ORTHANC_FRAMEWORK_VERSION_IS_ABOVE(1, 7, 2)
+    Orthanc::Logging::InitializePluginContext(context);
+#else
     Orthanc::Logging::Initialize(context);
+#endif
 
     // Limit the number of PNG transcoders to the number of available
     // hardware threads (e.g. number of CPUs or cores or
@@ -324,7 +344,7 @@ extern "C"
 
     OrthancPluginSetDescription(context, "Provides a Web viewer of whole-slide microscopic images within Orthanc.");
 
-    orthanc_.reset(new OrthancPlugins::OrthancPluginConnection);
+    orthanc_.reset(new OrthancWSI::OrthancPluginConnection);
     cache_.reset(new OrthancWSI::DicomPyramidCache(*orthanc_, 10 /* Number of pyramids to be cached - TODO parameter */));
 
     OrthancPluginRegisterOnChangeCallback(OrthancPlugins::GetGlobalContext(), OnChangeCallback);
