@@ -2,7 +2,7 @@
  * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012-2016 Sebastien Jodogne, Medical Physics
  * Department, University Hospital of Liege, Belgium
- * Copyright (C) 2017-2020 Osimis S.A., Belgium
+ * Copyright (C) 2017-2021 Osimis S.A., Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -63,8 +63,6 @@ $(document).ready(function() {
       success : function(series) {
         var width = series['TotalWidth'];
         var height = series['TotalHeight'];
-        var tileWidth = series['TileWidth'];
-        var tileHeight = series['TileHeight'];
         var countLevels = series['Resolutions'].length;
 
         // Maps always need a projection, but Zoomify layers are not geo-referenced, and
@@ -99,7 +97,7 @@ $(document).ready(function() {
             tileGrid: new ol.tilegrid.TileGrid({
               extent: extent,
               resolutions: series['Resolutions'].reverse(),
-              tileSize: [tileWidth, tileHeight]
+              tileSizes: series['TilesSizes'].reverse()
             })
           }),
           wrapX: false,
